@@ -25,12 +25,18 @@ else:
 __all__ = (
     "DeleteThingShadowRequestRequestTypeDef",
     "DeleteThingShadowResponseTypeDef",
+    "GetRetainedMessageRequestRequestTypeDef",
+    "GetRetainedMessageResponseTypeDef",
     "GetThingShadowRequestRequestTypeDef",
     "GetThingShadowResponseTypeDef",
     "ListNamedShadowsForThingRequestRequestTypeDef",
     "ListNamedShadowsForThingResponseTypeDef",
+    "ListRetainedMessagesRequestRequestTypeDef",
+    "ListRetainedMessagesResponseTypeDef",
+    "PaginatorConfigTypeDef",
     "PublishRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
+    "RetainedMessageSummaryTypeDef",
     "UpdateThingShadowRequestRequestTypeDef",
     "UpdateThingShadowResponseTypeDef",
 )
@@ -64,6 +70,24 @@ DeleteThingShadowResponseTypeDef = TypedDict(
     },
 )
 
+GetRetainedMessageRequestRequestTypeDef = TypedDict(
+    "GetRetainedMessageRequestRequestTypeDef",
+    {
+        "topic": str,
+    },
+)
+
+GetRetainedMessageResponseTypeDef = TypedDict(
+    "GetRetainedMessageResponseTypeDef",
+    {
+        "topic": str,
+        "payload": bytes,
+        "qos": int,
+        "lastModifiedTime": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredGetThingShadowRequestRequestTypeDef = TypedDict(
     "_RequiredGetThingShadowRequestRequestTypeDef",
     {
@@ -126,6 +150,34 @@ ListNamedShadowsForThingResponseTypeDef = TypedDict(
     },
 )
 
+ListRetainedMessagesRequestRequestTypeDef = TypedDict(
+    "ListRetainedMessagesRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+ListRetainedMessagesResponseTypeDef = TypedDict(
+    "ListRetainedMessagesResponseTypeDef",
+    {
+        "retainedTopics": List["RetainedMessageSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
 _RequiredPublishRequestRequestTypeDef = TypedDict(
     "_RequiredPublishRequestRequestTypeDef",
     {
@@ -136,6 +188,7 @@ _OptionalPublishRequestRequestTypeDef = TypedDict(
     "_OptionalPublishRequestRequestTypeDef",
     {
         "qos": int,
+        "retain": bool,
         "payload": Union[bytes, IO[bytes], StreamingBody],
     },
     total=False,
@@ -159,6 +212,17 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+RetainedMessageSummaryTypeDef = TypedDict(
+    "RetainedMessageSummaryTypeDef",
+    {
+        "topic": str,
+        "payloadSize": int,
+        "qos": int,
+        "lastModifiedTime": int,
+    },
+    total=False,
+)
+
 _RequiredUpdateThingShadowRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateThingShadowRequestRequestTypeDef",
     {
